<nav aria-label="breadcrumb">
    <ol class="breadcrumb">
        {% for obj in object.get_breadcrumbs %}
            {% if forloop.last %}
                <li class="breadcrumb-item active" aria-current="page">{{ obj.title }}</li>
            {% else %}
                <li class="breadcrumb-item"><a href="{{ obj.get_absolute_url }}">{{ obj.title }}</a></li>
            {% endif %}
        {% endfor %}
    </ol>
</nav>
